@@ -9,6 +9,7 @@ import re
 import sys
 from collections import ChainMap
 from contextlib import suppress
+from pathlib import Path
 from typing import TYPE_CHECKING, Any, BinaryIO, ClassVar, Iterator, Mapping, Sequence
 
 from griffe.collections import LinesCollection, ModulesCollection
@@ -52,6 +53,8 @@ patch_loggers(get_logger)
 class PythonHandler(BaseHandler):
     """The Python handler class."""
 
+    name: str = "python"
+    """The handler's name."""
     domain: str = "py"  # to match Sphinx's default domain
     """The cross-documentation domain/language for this handler."""
     enable_inventory: bool = True
@@ -194,7 +197,7 @@ class PythonHandler(BaseHandler):
         config_file_path: str | None = None,
         paths: list[str] | None = None,
         locale: str = "en",
-        load_external_modules: bool = False,
+        load_external_modules: bool | None = None,
         **kwargs: Any,
     ) -> None:
         """Initialize the handler.
@@ -208,21 +211,42 @@ class PythonHandler(BaseHandler):
             **kwargs: Same thing, but with keyword arguments.
         """
         super().__init__(*args, **kwargs)
+
+        # Warn if user overrides base templates.
+        if custom_templates := kwargs.get("custom_templates", ()):
+            config_dir = Path(config_file_path or "./mkdocs.yml").parent
+            for theme_dir in config_dir.joinpath(custom_templates, "python").iterdir():
+                if theme_dir.joinpath("_base").is_dir():
+                    logger.warning(
+                        f"Overriding base template '{theme_dir.name}/_base/<template>.html.jinja' is not supported, "
+                        f"override '{theme_dir.name}/<template>.html.jinja' instead",
+                    )
+
         self._config_file_path = config_file_path
         self._load_external_modules = load_external_modules
         paths = paths or []
+
+        # Expand paths with glob patterns.
         glob_base_dir = os.path.dirname(os.path.abspath(config_file_path)) if config_file_path else "."
         with chdir(glob_base_dir):
             resolved_globs = [glob.glob(path) for path in paths]
         paths = [path for glob_list in resolved_globs for path in glob_list]
+
+        # By default, add the directory of the config file to the search paths.
         if not paths and config_file_path:
             paths.append(os.path.dirname(config_file_path))
-        search_paths = [path for path in sys.path if path]  # eliminate empty path
+
+        # Initialize search paths from `sys.path`, eliminating empty paths.
+        search_paths = [path for path in sys.path if path]
+
         for path in reversed(paths):
+            # If it's not absolute, make path relative to the config file path, then make it absolute.
             if not os.path.isabs(path) and config_file_path:
                 path = os.path.abspath(os.path.join(os.path.dirname(config_file_path), path))  # noqa: PLW2901
+            # Don't add duplicates.
             if path not in search_paths:
                 search_paths.insert(0, path)
+
         self._paths = search_paths
         self._modules_collection: ModulesCollection = ModulesCollection()
         self._lines_collection: LinesCollection = LinesCollection()
@@ -272,7 +296,7 @@ class PythonHandler(BaseHandler):
         if unknown_module:
             extensions = self.normalize_extension_paths(final_config.get("extensions", []))
             loader = GriffeLoader(
-                extensions=load_extensions(extensions),
+                extensions=load_extensions(*extensions),
                 search_paths=self._paths,
                 docstring_parser=parser,
                 docstring_options=parser_options,
@@ -321,7 +345,7 @@ class PythonHandler(BaseHandler):
     def render(self, data: CollectorItem, config: Mapping[str, Any]) -> str:  # noqa: D102 (ignore missing docstring)
         final_config = ChainMap(config, self.default_config)  # type: ignore[arg-type]
 
-        template_name = rendering.do_get_template(data)
+        template_name = rendering.do_get_template(self.env, data)
         template = self.env.get_template(template_name)
 
         # Heading level is a "state" variable, that will change at each step
@@ -374,7 +398,13 @@ class PythonHandler(BaseHandler):
             },
         )
 
-    def update_env(self, md: Markdown, config: dict) -> None:  # noqa: D102 (ignore missing docstring)
+    def update_env(self, md: Markdown, config: dict) -> None:
+        """Update the Jinja environment with custom filters and tests.
+
+        Parameters:
+            md: The Markdown instance.
+            config: The configuration dictionary.
+        """
         super().update_env(md, config)
         self.env.trim_blocks = True
         self.env.lstrip_blocks = True
@@ -444,7 +474,7 @@ def get_handler(
     config_file_path: str | None = None,
     paths: list[str] | None = None,
     locale: str = "en",
-    load_external_modules: bool = False,
+    load_external_modules: bool | None = None,
     **config: Any,  # noqa: ARG001
 ) -> PythonHandler:
     """Simply return an instance of `PythonHandler`.
